<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>RecentFiles</name>
    <message>
        <source>Load/Save</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Load / Save</translation>
    </message>
    <message>
        <location filename="../RecentFiles.js" line="+35"/>
        <source>Recent Files</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ostatnie pliki</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <location filename="../RecentFilesInit.js" line="+51"/>
        <source>&amp;Clear List</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Wyczyść listę</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Open &amp;Recent</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ostatnio otwa&amp;rte</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Recent files history size:</source>
        <translation>Rozmiar historii ostatnich plików:</translation>
    </message>
</context>
</TS>
